@@ -1,6 +1,7 @@
 /*
  * potool is a program aiding editing of po files
  * Copyright (C) 1999-2002 Zbigniew Chyla
+ * Copyright (C) 2000-2012 Marcin Owsiany <porridge@debian.org>
  *
  * see LICENSE for licensing info
  */
@@ -20,6 +21,10 @@ typedef struct {
 	GSList *spec;
 } PoComments;
 
+typedef struct {
+	char *ctx, *id, *id_plural;
+} PoPrevious;
+
 typedef struct {
 	char *str;
 	int n;
@@ -27,18 +32,12 @@ typedef struct {
 
 typedef struct {
 	PoComments comments;
+	PoPrevious previous;
 	gboolean is_fuzzy, is_c_format;
 	char *ctx, *id, *id_plural, *str;
 	GSList *msgstrxs;
 } PoEntry;
 
-typedef struct {
-	PoComments comments;
-	gboolean is_fuzzy, is_c_format;
-	char *ctx, *id, *id_plural, *str;
-	GSList *msgstrxs;
-} PoObsoleteEntry;
-
 typedef struct {
 	GSList *entries, *obsolete_entries;
 } PoFile;
